@@ -30,6 +30,7 @@
 #include "code/codetools.h"
 #include "code/image.h"
 #include "code/rawdata.h"
+#include "code/prettyprinting.h"
 #include "codeactiona.h"
 
 #include <QDesktopWidget>
@@ -39,6 +40,7 @@
 #include <QLocale>
 #include <QProgressDialog>
 #include <QScriptEngine>
+#include <QScriptValueIterator>
 
 namespace LibExecuter
 {
@@ -117,6 +119,8 @@ namespace LibExecuter
         mActionaVersion = actionaVersion;
 		mScriptVersion = scriptVersion;
 		mIsActExec = isActExec;
+
+        Code::setupPrettyPrinting(*mScriptEngine);
 		
 		mScriptEngineDebugger.attachTo(mScriptEngine);
 		mDebuggerWindow = mScriptEngineDebugger.standardWindow();
