@@ -44,6 +44,7 @@
 #include <QMenu>
 
 #include <limits>
+#include <algorithm>
 
 ActionDialog::ActionDialog(QAbstractItemModel *completionModel, ActionTools::Script *script, ActionTools::ActionDefinition *actionDefinition, const QString &localeName, QWidget *parent)
 	: QDialog(parent),
@@ -314,7 +315,7 @@ QMenu *ActionDialog::createVariablesMenu(QWidget *parent) const
     }
 
     QStringList variableList = thisActionsVariables.unite(mOtherActionsVariables).toList();
-    qSort(variableList);
+    std::sort(variableList.begin(), variableList.end());
 
     if(variableList.isEmpty())
         return 0;
@@ -425,6 +426,9 @@ void ActionDialog::postInit()
 			QComboBox *exceptionActionComboBox = qobject_cast<QComboBox *>(mExceptionsLayout->itemAtPosition(i, 1)->widget());
 			ActionTools::LineComboBox *lineComboBox = qobject_cast<ActionTools::LineComboBox *>(mExceptionsLayout->itemAtPosition(i, 2)->widget());
 
+            lineComboBox->setCompletionModel(mCompletionModel);
+            lineComboBox->setParameterContainer(this);
+
 			exceptionActionComboBox->setCurrentIndex(exceptionActionInstance.action());
 			lineComboBox->codeLineEdit()->setText(exceptionActionInstance.line());
 			lineComboBox->setEnabled(exceptionActionInstance.action() == ActionTools::ActionException::GotoLineExceptionAction);
