@@ -86,6 +86,8 @@
 #include <QX11Info>
 #endif
 
+#include <algorithm>
+
 #if (QT_VERSION < QT_VERSION_CHECK(5, 0, 0))
 QTM_USE_NAMESPACE
 #endif
@@ -128,11 +130,16 @@ MainWindow::MainWindow(QxtCommandOptions *commandOptions, ProgressSplashScreen *
 
 	ui->setupUi(this);
 
+    mScriptProgressDialog->close();
     mScriptProgressDialog->setWindowModality(Qt::ApplicationModal);
     mScriptProgressDialog->setCancelButton(0);
     mScriptProgressDialog->setAutoClose(false);
     mScriptProgressDialog->setMinimumDuration(0);
 
+#ifndef ACT_NO_UPDATER
+    mUpdaterProgressDialog->close();
+#endif
+
     if(Global::ACTIONA_VERSION >= Tools::Version(1, 0, 0))
 		ui->reportBugPushButton->setVisible(false);
 	
@@ -739,6 +746,8 @@ void MainWindow::on_actionExport_executable_triggered()
     mScript->write(&file, Global::ACTIONA_VERSION, Global::SCRIPT_VERSION);
 	file.close();
 
+    mScriptProgressDialog->close();
+
 	progressDialog.setLabelText(tr("Writing config file..."));
 	QApplication::processEvents();
 
@@ -924,7 +933,7 @@ void MainWindow::on_actionCopy_triggered()
 void MainWindow::on_actionPaste_triggered()
 {
 	QList<int> selection = selectedRows();
-	qSort(selection);
+    std::sort(selection.begin(), selection.end());
 	int destination = mScript->actionCount();
 
 	if(selection.count() > 0)
